<?php
/**
 * Created by PhpStorm.
 * User: migue
 * Date: 02/06/2017
 * Time: 12:06
 */

namespace Oct8ne\Oct8ne\Controller\Frame;

use \Magento\Framework\App\Action\Context;
use \Oct8ne\Oct8ne\Helper\ResponseHelper;
use \Magento\Framework\App\Config\ScopeConfigInterface;
use \Magento\Sales\Model\ResourceModel\Order\CollectionFactory;
use \Oct8ne\Oct8ne\Helper\Oct8neContextHelper;
use \Magento\Framework\Pricing\PriceCurrencyInterface as CurrencyHelper;
use \Magento\Sales\Api\OrderRepositoryInterface;
use \Magento\Framework\Api\SearchCriteriaBuilder;


class GetOrderDetails extends \Magento\Framework\App\Action\Action
{

    /**
     * @var ProductSummaryHelper|Oct8neModuleInfoHelper
     */
    protected $_oct8necontext;

    protected $_scopeconfig;

    protected $_orderCollectionFactory;

    /**
     * @var Context
     */
    protected $_context;

    protected $_responseHelper;


    protected $_currencyHelper;

    protected $_orderRepository;

	protected $_searchCriteriaBuilder;
    /**
     * Inyeccion de dependencias. Inyectamos lo que nos hace falta
     * GetAdapterInfo constructor.
     * @param Context $context
     * @param ProductSummaryHelper $helper
     */

    public function __construct(Context $context, Oct8neContextHelper $oct8necontext, ResponseHelper $responseHelper, ScopeConfigInterface $scope, CollectionFactory $orderCollectionFactory, CurrencyHelper $currencyHelper, OrderRepositoryInterface $orderRepository, SearchCriteriaBuilder $searchCriteriaBuilder)
    {
        $this->_context = $context;
        $this->_oct8necontext = $oct8necontext;
        $this->_responseHelper = $responseHelper;
        $this->_scopeconfig = $scope;
        $this->_orderCollectionFactory = $orderCollectionFactory;
        $this->_currencyHelper = $currencyHelper;
        $this->_orderRepository = $orderRepository;
		$this->_searchCriteriaBuilder = $searchCriteriaBuilder;


        parent::__construct($context);
    }

    /**
     * Todos los controladores ejecutan el execute despues de la construccion
     * @return \Magento\Framework\View\Result\Page
     */
    public function execute()
    {

        $oct8ne_context = $this->_oct8necontext->getOct8neContext();

        
        $apiToken = $this->_context->getRequest()->getParam("apiToken");
        $locale = $this->_context->getRequest()->getParam("locale");
        $currency = $this->_context->getRequest()->getParam("currency");
        $id = $this->_context->getRequest()->getParam("reference");       
        $email = $this->_context->getRequest()->getParam("email");       

        $token = $this->_scopeconfig->getValue("Oct8ne/user/token", \Magento\Store\Model\ScopeInterface::SCOPE_STORE);

        if($token != $apiToken) return $this->_responseHelper->buildResponse(array()); 
		
		
		$this->_searchCriteriaBuilder = $this->_searchCriteriaBuilder->addFilter('increment_id', $id, 'eq');

        if(!empty($email)) {
		    $this->_searchCriteriaBuilder = $this->_searchCriteriaBuilder->addFilter('customer_email', $email, 'eq');
        }

		$this->_searchCriteriaBuilder = $this->_searchCriteriaBuilder->create();


		$orderList = $this->_orderRepository->getList($this->_searchCriteriaBuilder)->getItems();

		$order = reset($orderList);

        if (empty($order)) {

            return $this->_responseHelper->buildResponse(array());

        }

        $currencyOrder = "";
        $total = strval($this->_currencyHelper->convertAndRound($order->getGrandTotal(), NULL,$currency, 2));

        if($oct8ne_context["context_currency"] != $currency) {
            $currencyOrder = $currency;

        } else {
            $currencyOrder = $oct8ne_context["context_currency"];
            $total = $order->getGrandTotal();
        }

        $tracksCollection = $order->getTracksCollection();
        $trackNumbers = array();

        foreach ($tracksCollection->getItems() as $track) {

            $tracknumber = $track->getTrackNumber();
            $trakURL = $track->getUrl();

            $aux = array();
            $aux["trackNumber"] = isset($tracknumber) ? $tracknumber : "";
            $aux["trackURL"] = isset($trakURL) ? $trakURL : "";
            $trackNumbers = $aux;

        }

        $products = array();

        foreach($order->getAllItems() as $item) {

                $aux = array();
                $aux["quantity"] = strval(intval($item->getQtyOrdered()));
                $aux["name"] =  $item->getName();
                $products[] = $aux;
            }

        $histories = $order->getStatusHistories();

        $comments = array();

        foreach($histories as $history) {

            $aux = array();
            $aux["message"] = $history->getComment();
            $comments[] = $aux;
        }


        $data = array(
            "date" => $order->getCreatedAt(),
            
            //"reference" => $order->getEntityId(),
            "reference" => $order->getIncrementId(),
            "total" => $total,
            "currency" => $currencyOrder,    
            "labelState" => $order->getStatusLabel(),
            "deliveryDate" => "",
            "carrier" => $order->getShippingMethod(),
			"trackNumber" => $trackNumbers["trackNumber"],
			"trackURL" => $trackNumbers["trackURL"],
            "products" => $products,
            "comments" => $comments
        );     
        
    
        return $this->_responseHelper->buildResponse($data);

    }
}